| PopSim | R Documentation |
Resampling stochastic simulator for a single density-independent population.
PopSim(Rs, N0, years = 50, sims = 10)
Rs |
vector of observed annual growth rates (N[t+1]/N[t]). |
N0 |
initial population size. |
years |
number of years to simulate. |
sims |
number of simulated populations. |
Designed to simulate trajectories based on resampled observed N[t+1]/N[t].
Returns a matrix of population sizes for time = t (rows) for each replicated population (columns).
Stevens, M.H.H. (2009) A Primer of Ecology with R. Use R! Series. Springer.
sparrows
lambdas <- runif(10, .5, 1.5)
out <- PopSim(Rs=lambdas, years=50, N0=50)
matplot(0:50, out, type='l')
summary(out[51,])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.