| clogistic | R Documentation |
A function for continuous logistic growth, for use with ode in the
deSolve package.
clogistic(times, y, parms)
times |
times points that will return N |
y |
N |
parms |
a vector of logistic growth parameters; the first must be r, and the second must be alpha (1/K). |
The user does not put these directly into this function, but rather uses
ode in the deSolve package.
The function implements the logistic growth equation
\frac{dN}{dt} = rN\left(1-\alpha N\right)
or equivalently
\frac{dN}{dt} = rN\left(\frac{K-N}{K}\right)
Returns of list of one component (required by ode).
Hank Stevens <HankStevens@miamioh.edu>
Stevens. M.H.H. (2009) A Primer of Ecology with R. Use R! Series. Springer.
dlogistic, thetalogistic,
levins, lvcomp2, lvcompg
library(deSolve)
p <- c(r=1, alpha=.01)
time <- 1:10
initialN <- 10
out <- ode(y=initialN, times=time,
func=clogistic, parms=p)
plot(time, out[,-1], type='l')
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.