coneflowerseeds: Smooth coneflower seed data

coneflowerseedsR Documentation

Smooth coneflower seed data

Description

A data set containing size and seed set of individual coneflowers.

Usage

data(coneflowerseeds)

Format

A data frame with 136 rows and 5 variables:

logAs

natural log of total leaf area in the first year

seeds

number of seeds produced in the first year

Examples


data(coneflowerseeds)
ggplot2::qplot(logAs, seeds, data=coneflowerseeds)


primer documentation built on June 5, 2026, 5:07 p.m.