PrevUpHomeNext

Core

class error
class expected
function push
function read
class result
metafunction adapt
concept L_Reg_sequence
concept userdata
class lua_ref
class lua_ref_seq
class bound_function
class coroutine

The core features of primer are general-purpose lua binding facilities.

They do not rely on lua eris, and can be useful in an application which only uses vanilla lua 5.3 or 5.2. They also don't particularly rely on much of the standard library.

These features serve such purposes as:


PrevUpHomeNext