| primer-package | R Documentation |
Functions are primarily functions for systems of ordinary differential equations, difference equations, and eigenanalysis and projection of demographic matrices; data are for examples.
Stevens, M.H.H. (2009) A Primer of Ecology with R Springer, 2nd printing.
lvcompg, ode
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.