weeds: Percent cover of six perennial herbaceous plants

weedsR Documentation

Percent cover of six perennial herbaceous plants

Description

Percent cover of six of the most common herbaceous perennial species from the Buell-Small long term succession study (http://www.ecostudies.org/bss/). Data are plot-level visual estimates of percent cover.

Format

A data frame with 15140 observations on the following 8 variables.

X

a numeric vector

Genus

a factor with levels Aster, Euthamia, Solidago

Epithet

a factor with levels canadensis, gigantea, graminifolia, novae-angliae, pilosus, rugosa

FieldName

a factor with levels C3, C4, C5, C6, C7, D1, D2, D3, E1, E2

Age

a numeric vector indicating the number of years of succession, since abandonment from agriculture.

PlotId

a numeric vector

Cover

a numeric vector; percent cover, estimated visually.

Species

a factor with levels A.novae-angliae, A.pilosus, E.graminifolia, S.canadensis, S.gigantea, S.rugosa

Data graciously provided by Scott Meiners (Eastern Illinois University, http://www.ecostudies.org/bss/).

References

Stevens, M.H.H. (2009) A Primer of Ecology with R. Use R! Series. Springer.

Examples


data(weeds)
str(weeds);
# lattice::xyplot(Cover ~ Age, data=weeds, groups=Species,
# type=c("a"), auto.key=list(lines=TRUE, points=FALSE, columns=3),
# ylim=c(-1,20))


primer documentation built on June 5, 2026, 5:07 p.m.