The primer::api namespace contains all the types which
are specific to constructing API objects.
An API object is a collection of features and methods which can be exposed
to a lua VM. Each API object is supposed to be used with one and only one
VM. It provides three methods initialize,
persist, and unpersist.
You'll need to use these objects if you want to use a programming style like in the quick start examples for your application.
You need to link with lua eris, not just lua, to use these objects.