| coneflowerseeds | R Documentation |
A data set containing size and seed set of individual coneflowers.
data(coneflowerseeds)
A data frame with 136 rows and 5 variables:
natural log of total leaf area in the first year
number of seeds produced in the first year
data(coneflowerseeds)
ggplot2::qplot(logAs, seeds, data=coneflowerseeds)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.